@@ -1,4 +1,5 @@
 ### R code from vignette source 'Trees.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: Trees.Rnw:49-52
@@ -9,15 +10,16 @@ options("show.signif.stars" = FALSE)
 
 
 ###################################################
-### code chunk number 2: Trees.Rnw:68-71
+### code chunk number 2: Trees.Rnw:68-72
 ###################################################
+library(ape)
 library(phangorn)
 fdir <- system.file("extdata/trees", package = "phangorn")
-primates <- read.phyDat(file.path(fdir, "primates.dna"), format = "phylip")
+primates <- read.phyDat(file.path(fdir, "primates.dna"), format = "interleaved")
 
 
 ###################################################
-### code chunk number 3: Trees.Rnw:77-80
+### code chunk number 3: Trees.Rnw:78-81
 ###################################################
 dm  <- dist.ml(primates)
 treeUPGMA  <- upgma(dm)
@@ -44,14 +46,14 @@ plot(treeNJ, "unrooted", main="NJ")
 
 
 ###################################################
-### code chunk number 6: Trees.Rnw:102-104
+### code chunk number 6: Trees.Rnw:103-105
 ###################################################
 parsimony(treeUPGMA, primates)
 parsimony(treeNJ, primates)
 
 
 ###################################################
-### code chunk number 7: Trees.Rnw:107-110
+### code chunk number 7: Trees.Rnw:108-111
 ###################################################
 treePars  <- optim.parsimony(treeUPGMA, primates)
 treeRatchet  <- pratchet(primates, trace = 0)
@@ -59,90 +61,90 @@ parsimony(c(treePars, treeRatchet), primates)
 
 
 ###################################################
-### code chunk number 8: Trees.Rnw:113-114 (eval = FALSE)
+### code chunk number 8: Trees.Rnw:114-115 (eval = FALSE)
 ###################################################
 ## (trees <- bab(subset(primates,1:10)))
 
 
 ###################################################
-### code chunk number 9: Trees.Rnw:120-122
+### code chunk number 9: Trees.Rnw:121-123
 ###################################################
 fit = pml(treeNJ, data=primates)
 fit
 
 
 ###################################################
-### code chunk number 10: Trees.Rnw:125-126
+### code chunk number 10: Trees.Rnw:126-127
 ###################################################
 methods(class="pml")
 
 
 ###################################################
-### code chunk number 11: Trees.Rnw:129-131
+### code chunk number 11: Trees.Rnw:130-132
 ###################################################
 fitJC  <- optim.pml(fit, TRUE)
 logLik(fitJC)
 
 
 ###################################################
-### code chunk number 12: Trees.Rnw:134-138
+### code chunk number 12: Trees.Rnw:135-139
 ###################################################
-fitGTR <- update(fit, k=4, inv=0.2) 
-fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE, 
+fitGTR <- update(fit, k=4, inv=0.2)
+fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE,
     rearrangement = "NNI", control = pml.control(trace = 0))
-fitGTR 
+fitGTR
 
 
 ###################################################
-### code chunk number 13: Trees.Rnw:143-146
+### code chunk number 13: Trees.Rnw:144-147
 ###################################################
-fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE, 
+fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE,
     rearrangement = "stochastic", control = pml.control(trace = 0))
-fitGTR 
+fitGTR
 
 
 ###################################################
-### code chunk number 14: Trees.Rnw:150-151
+### code chunk number 14: Trees.Rnw:151-152
 ###################################################
-anova(fitJC, fitGTR) 
+anova(fitJC, fitGTR)
 
 
 ###################################################
-### code chunk number 15: Trees.Rnw:154-155
+### code chunk number 15: Trees.Rnw:155-156
 ###################################################
-SH.test(fitGTR, fitJC) 
+SH.test(fitGTR, fitJC)
 
 
 ###################################################
-### code chunk number 16: Trees.Rnw:158-162
+### code chunk number 16: Trees.Rnw:159-163
 ###################################################
 AIC(fitJC)
-AIC(fitGTR) 
-AICc(fitGTR) 
-BIC(fitGTR) 
+AIC(fitGTR)
+AICc(fitGTR)
+BIC(fitGTR)
 
 
 ###################################################
-### code chunk number 17: Trees.Rnw:165-166
+### code chunk number 17: Trees.Rnw:166-167
 ###################################################
 load("Trees.RData")
 
 
 ###################################################
-### code chunk number 18: Trees.Rnw:168-169 (eval = FALSE)
+### code chunk number 18: Trees.Rnw:169-170 (eval = FALSE)
 ###################################################
 ## mt = modelTest(primates)
 
 
 ###################################################
-### code chunk number 19: Trees.Rnw:173-175
+### code chunk number 19: Trees.Rnw:174-176
 ###################################################
 library(xtable)
 print(xtable(mt, caption="Summary table of modelTest", label="tab:modelTest"), include.rownames=FALSE)
 
 
 ###################################################
-### code chunk number 20: Trees.Rnw:179-182
+### code chunk number 20: Trees.Rnw:180-183
 ###################################################
 env <- attr(mt, "env")
 ls(envir=env)
@@ -150,9 +152,9 @@ ls(envir=env)
 
 
 ###################################################
-### code chunk number 21: Trees.Rnw:185-187 (eval = FALSE)
+### code chunk number 21: Trees.Rnw:186-188 (eval = FALSE)
 ###################################################
-## bs = bootstrap.pml(fitJC, bs=100, optNni=TRUE, 
+## bs = bootstrap.pml(fitJC, bs=100, optNni=TRUE,
 ##     control = pml.control(trace = 0))
 
 
@@ -182,14 +184,14 @@ title("b)")
 
 
 ###################################################
-### code chunk number 24: Trees.Rnw:218-220
+### code chunk number 24: Trees.Rnw:219-221
 ###################################################
 options(prompt=" ")
 options(continue="  ")
 
 
 ###################################################
-### code chunk number 25: Trees.Rnw:222-251 (eval = FALSE)
+### code chunk number 25: Trees.Rnw:223-252 (eval = FALSE)
 ###################################################
 ## library(phangorn)
 ## file="myfile"
@@ -197,33 +199,33 @@ options(continue="  ")
 ## dm = dist.ml(dat, "F81")
 ## tree = NJ(dm)
 ## # as alternative for a starting tree:
-## tree <- pratchet(dat)          # parsimony tree 
+## tree <- pratchet(dat)          # parsimony tree
 ## tree <- nnls.phylo(tree, dm)   # need edge weights
 ## 
 ## 
-## # 1. alternative: quick and dirty: GTR + G 
+## # 1. alternative: quick and dirty: GTR + G
 ## fitStart = pml(tree, dat, k=4)
-## fit = optim.pml(fitStart, model="GTR", optGamma=TRUE, rearrangement="stochastic") 
-##  
-## # 2. alternative: preper with modelTest  
+## fit = optim.pml(fitStart, model="GTR", optGamma=TRUE, rearrangement="stochastic")
+## 
+## # 2. alternative: preper with modelTest
 ## mt <- modelTest(dat, tree=tree, multicore=TRUE)
 ## mt[order(mt$AICc),]
 ## # choose best model from the table according to AICc
 ## bestmodel <- mt$Model[which.min(mt$AICc)]
 ## 
 ## env = attr(mt, "env")
-## fitStart = eval(get("GTR+G+I", env), env) 
+## fitStart = eval(get("GTR+G+I", env), env)
 ## 
 ## # or let R search the table
-## fitStart = eval(get(bestmodel, env), env) 
-## # equivalent to:   fitStart = eval(get("GTR+G+I", env), env) 
-## fit = optim.pml(fitStart, rearrangement = "stochastic", 
+## fitStart = eval(get(bestmodel, env), env)
+## # equivalent to:   fitStart = eval(get("GTR+G+I", env), env)
+## fit = optim.pml(fitStart, rearrangement = "stochastic",
 ##     optGamma=TRUE, optInv=TRUE, model="GTR")
 ## bs = bootstrap.pml(fit, bs=100, optNni=TRUE, multicore=TRUE)
 
 
 ###################################################
-### code chunk number 26: Trees.Rnw:257-278 (eval = FALSE)
+### code chunk number 26: Trees.Rnw:258-279 (eval = FALSE)
 ###################################################
 ## library(phangorn)
 ## file="myfile"
@@ -231,17 +233,17 @@ options(continue="  ")
 ## dm = dist.ml(dat, model="JTT")
 ## tree = NJ(dm)
 ## 
-## # parallel will only work safely from command line 
+## # parallel will only work safely from command line
 ## # and not at all windows
-## (mt <- modelTest(dat, model=c("JTT", "LG", "WAG"), 
-##     multicore=TRUE)) 
+## (mt <- modelTest(dat, model=c("JTT", "LG", "WAG"),
+##     multicore=TRUE))
 ## # run all available amino acid models
 ## (mt <- modelTest(dat, model="all", multicore=TRUE))
 ## 
-## fitStart = eval(get(mt$Model[which.min(mt$BIC)], env), env) 
+## fitStart = eval(get(mt$Model[which.min(mt$BIC)], env), env)
 ## 
 ## fitNJ = pml(tree, dat, model="JTT", k=4, inv=.2)
-## fit = optim.pml(fitNJ, rearrangement = "stochastic", 
+## fit = optim.pml(fitNJ, rearrangement = "stochastic",
 ##     optInv=TRUE, optGamma=TRUE)
 ## fit
 ## 
@@ -249,14 +251,14 @@ options(continue="  ")
 
 
 ###################################################
-### code chunk number 27: Trees.Rnw:281-283
+### code chunk number 27: Trees.Rnw:282-284
 ###################################################
 options(prompt="> ")
 options(continue="+ ")
 
 
 ###################################################
-### code chunk number 28: Trees.Rnw:295-296
+### code chunk number 28: Trees.Rnw:296-297
 ###################################################
 toLatex(sessionInfo())
 
